Class: Shoe::Tasks::Ronn
Overview
Defines rake ronn</tt> to generate man pages from your
ronn sources.
To enable, create some man/*.ronn files.
To configure the date and organization fields for your man pages, set the date and the first of the authors in your gemspec, respectively.
Notes
-
It's best to include the generated man pages in your gem, so that gem-man can get to them.
-
Ronn becomes a prerequisite for rake build, so your man pages are sure to be up-to-date.
-
You may like to add a task :man => :ronn to your Rakefile. I felt a little uncomfortable clogging that namespace without your consent.
Instance Attribute Summary
Attributes inherited from Task
Instance Method Summary collapse
Methods inherited from Task
Constructor Details
This class inherits a constructor from Shoe::Tasks::Task
Instance Method Details
#active? ⇒ Boolean
27 28 29 |
# File 'lib/shoe/tasks/ronn.rb', line 27 def active? !ronn_files.empty? end |
#define ⇒ Object
31 32 33 34 35 36 37 38 39 |
# File 'lib/shoe/tasks/ronn.rb', line 31 def define begin require 'ronn' rescue LoadError warn "WARN: Please `gem install ronn`." else define_tasks end end |